import React, { useMemo } from "react";
import { Button, Card, Form, Input, Select } from "antd";
import useBool from "@/utils/hooks/useBool";
import { useSearchParams, useNavigate } from "react-router-dom";
import Page from "@/components/Page";
import { formItemLayout, tailFormItemLayout } from "@/utils/form";
import { postSysUser, putSysUser, getSysUserById } from "@/services/sysUser";
const { Option } = Select;

export default (props) => {

  const [loading, startLoading, cancelLoading] = useBool();
  const [submiting, startSubmit, cancelSubmit] = useBool();

  const [searchParams] = useSearchParams();
  const [form] = Form.useForm();
  const navigate = useNavigate();

  const id = searchParams.get("id");

  React.useEffect(() => {
    if (id) {
      console.log('---id--->', id)
      getSysUserById(id).then((res) => {
        console.log('res', res)
        form.setFieldsValue(res);
      })
    }
  }, [id])

  const onFinish = (values) => {
    startSubmit();
    if (id) {
      // console.log('---id--->', id)
      //修改
      putSysUser(id, values).then((res) => {
        cancelSubmit();
        navigate(-1);
      }).catch(() => {
        cancelSubmit();
      })
    } else {
      //新增
      postSysUser(values).then((res) => {
        cancelSubmit();
        navigate(-1)
      }).catch(() => {
        cancelSubmit();
      })
    }
  }

  return (
    <Page>
      <Card loading={loading}>
        <Form
          onFinish={onFinish}
          form={form}
          {...formItemLayout}
          scrollToFirstError
          style={{ maxWidth: "1000px" }}
        >
          <Form.Item
            name="userName"
            label="姓名"
            rules={[
              {
                required: true,
                message: "请填写姓名",
              },
            ]}
          >
            <Input placeholder="请输入姓名" />
          </Form.Item>
          <Form.Item name="phone" label="电话">
            <Input placeholder="请输入电话" />
          </Form.Item>

          <Form.Item {...tailFormItemLayout}>
            <Button loading={submiting} type="primary" htmlType="submit">
              保存
            </Button>
            <Button style={{ marginLeft: "2em" }} onClick={() => navigate(-1)}>
              返回
            </Button>
          </Form.Item>
        </Form>
      </Card>
    </Page>
  );
};
